@@ -27,22 +27,41 @@
 //testing for daemon
 #include <stdlib.h>
 
+#include <QSplashScreen>
+#include <QtSql> 
+#include <QMessageBox> 
+
 #include "mainwindow.h"
 
+bool createConnection()
+{
+	QSqlDatabase db = QSqlDatabase::addDatabase("QSQLITE");
+	//db.setHostName("test");
+	db.setDatabaseName("/root/segatex/sqlrefpolicy.db");
+	//db.setUserName("test");
+	//db.setPassword("test");
+	if(!db.open()){
+		QMessageBox::critical(0, QObject::tr("Database Error"),
+			db.lastError().text());
+		return false;
+	}
+	return true;
+}
 int main(int argc, char *argv[])
 {
 	QApplication app(argc, argv);
+	if(!createConnection())
+		//return 1;
+		return false;
 	QTranslator appTranslator;
 	appTranslator.load(QString("segatex_") + QTextCodec::locale(),
 				"/root/segatex");
 	app.installTranslator(&appTranslator);
-	//QSplashScreen *splash = new QSplashScreen(QPixmap::fromMimeSource("/root/segatex/splash.png"));
-	//QPixmap splashIcon = QPixmap(":/document.png");
-	QPixmap splashIcon = QPixmap(":/root/segatex/splash.png");
-	QSplashScreen *splash = new QSplashScreen(splashIcon);
+	QSplashScreen *splash = new QSplashScreen;
+	splash->setPixmap(QPixmap(":/images/splash.png"));
 
 	splash->show();
-	splash->message(QObject::tr("Setting up the main window..."),
+	splash->showMessage(QObject::tr("Setting up the main window..."),
 			Qt::AlignRight | Qt::AlignTop, Qt::white);
 	//QApplication app(argc, argv);
 	MainWindow mainWin;
