@@ -99,6 +99,7 @@
 #include "restorecon.h"
 #include "mainwindow.h"
 #include "downloader.h"
+#include "sqlrefpolicy.h"
 
  MainWindow::MainWindow()
 {
@@ -143,6 +144,7 @@
 	seeprocess_o = 0;
 	restorecon_o = 0;
 	downloader_o = 0;
+	sqlrefpolicy_o = 0;
 
 	createActions();
 	createMenus();
@@ -150,8 +152,7 @@
 	createStatusBar();
 	updateMenus();
 	readSettings();
-	//setWindowTitle(tr("MDI"));
-	setWindowTitle(tr("segatex-7.20"));
+	setWindowTitle(tr("segatex-7.72"));
 	QPixmap myIcon1 = QPixmap(":/images/icon.png");
 	this->setIcon(myIcon1);
  }
@@ -243,18 +244,10 @@ void MainWindow::open()
      if (activeMdiChild())
          activeMdiChild()->paste();
  }
-/*
- void MainWindow::about()
- {
-    QMessageBox::about(this, tr("About MDI"),
-             tr("The <b>MDI</b> example demonstrates how to write multiple "
-                "document interface applications using Qt."));
- }
-*/
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About segatex"),
-		tr("<h2>segatex-7.20</h2>"
+		tr("<h2>segatex-7.72</h2>"
 		"<p>Copyright &copy; 2007-2009"
 		"<p>Shintaro Fujiwara."
 		"<p>segatex is a SELinux tool"
@@ -449,6 +442,11 @@ void MainWindow::createActions()
 	connect(default_policyAct, SIGNAL(activated()), segatex_state, SLOT(default_policy_type()));
 	connect(default_policyAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 
+	sqlrefpolicyAct = new QAction(tr("&Refpolicy Analizer"), this);
+	sqlrefpolicyAct->setStatusTip(tr("Analyze refpolicy"));
+	connect(sqlrefpolicyAct, SIGNAL(activated()), this, SLOT(sqlrefpolicy()));
+	connect(sqlrefpolicyAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
 	selinuxYumAct = new QAction(tr("&Yum install/update"), this);
 	selinuxYumAct->setStatusTip(tr("Yum install/update SELinux related RPMs."));
 	connect(selinuxYumAct, SIGNAL(activated()), this, SLOT(yum_selinux()));
@@ -573,6 +571,7 @@ void MainWindow::createMenus()
 	auditMenu->addAction(ausearchAct);
 
 	policyMenu = menuBar()->addMenu(tr("&Policy"));
+	policyMenu->addAction(sqlrefpolicyAct);
 	policyMenu->addAction(selinuxYumAct);
 	policyMenu->addAction(enforcingAct);
 	policyMenu->addAction(check_selinuxAct);
@@ -626,7 +625,6 @@ void MainWindow::createMenus()
  }
  void MainWindow::createStatusBar()
  {
-     //statusBar()->showMessage(tr("Ready"));
 	readyLabel = new QLabel(tr(" Ready"), this);
 
 	modLabel = new QLabel(tr(" MOD "), this);
@@ -904,6 +902,15 @@ void MainWindow::downloader()
 	downloader_o->raise();
 	downloader_o->setActiveWindow();
 }
+void MainWindow::sqlrefpolicy()
+{
+	//if(!sqlrefpolicy_o) {
+		sqlrefpolicy_o = new Sqlrefpolicy(this);
+	//}
+	sqlrefpolicy_o->show();
+	sqlrefpolicy_o->raise();
+	sqlrefpolicy_o->setActiveWindow();
+}
 void MainWindow::howtouse()
 {
 	QMessageBox::about(this, tr("How to use"),
@@ -926,6 +933,7 @@ void MainWindow::howtouse()
 		" You can restorecon."
 		" You can add/delete Linux user."
 		" You can ftp download."
+		" You can analyze refpolicy."
 		"<p><font color=\"blue\">[segatex_editor]</font>"
 		"<p>Push break .te or .if"
 		""));
