@@ -20,12 +20,17 @@
 
 #include <qlayout.h>
 #include <qpushbutton.h>
-#include <qprocess.h>
+#include <q3process.h>
 #include <qradiobutton.h>
-#include <qbuttongroup.h>
+#include <q3buttongroup.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
-#include <qprocess.h>
+#include <q3textedit.h>
+#include <q3process.h>
+//Added by qt3to4:
+#include <Q3TextStream>
+#include <Q3HBoxLayout>
+#include <QLabel>
+#include <Q3VBoxLayout>
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -43,7 +48,7 @@ using namespace std;
 Policygeneration::Policygeneration(QWidget *parent, const char *name): QDialog(parent, name)
 {
 	setCaption(tr("Policygeneration Process"));
-	textEdit1 = new QTextEdit(this);
+	textEdit1 = new Q3TextEdit(this);
 	textEdit1->setPaletteBackgroundColor(QColor(0,254,100));
 	semanageEditLabel = new QLabel(tr("policy_module name:"), this );
 	semanageEditLabel2 = new QLabel(tr("executable path:"), this );
@@ -81,14 +86,14 @@ Policygeneration::Policygeneration(QWidget *parent, const char *name): QDialog(p
 	//set textEdit smanage such and such -l
 	policygeneration_base_process();
 
-	mainLayout = new QVBoxLayout(this);
+	mainLayout = new Q3VBoxLayout(this);
 	mainLayout->setMargin(11);
 
-	upperLayout = new QVBoxLayout;
+	upperLayout = new Q3VBoxLayout;
 	upperLayout->addWidget(textEdit1);
 
-	middleLayout = new QVBoxLayout;
-	leftLayout = new QVBoxLayout;
+	middleLayout = new Q3VBoxLayout;
+	leftLayout = new Q3VBoxLayout;
 	
 	leftLayout->addWidget(semanageEditLabel);
 	leftLayout->addWidget(semanageEditLineEdit);
@@ -103,13 +108,13 @@ Policygeneration::Policygeneration(QWidget *parent, const char *name): QDialog(p
 	leftLayout->addWidget(initscriptCheckBox);
 	leftLayout->addWidget(networkCheckBox);
 
-	rightLayout = new QHBoxLayout;
+	rightLayout = new Q3HBoxLayout;
 	rightLayout->addStretch();
 	rightLayout->addWidget(policygenerationButton);
 
 	middleLayout->addLayout(leftLayout);
 
-	footLayout = new QHBoxLayout;
+	footLayout = new Q3HBoxLayout;
 	footLayout->addStretch();
 	footLayout->addWidget(closeButton);
 
@@ -150,7 +155,7 @@ void Policygeneration::policygeneration_button_clicked_ok()
 void Policygeneration::policygeneration_button_clicked_process(QString semanageEditLineEdit_str, QString semanageEditLineEdit2_str, QString semanageEditLineEdit3_str,QString semanageEditLineEdit4_str, QString semanageEditLineEdit5_str)
 {
         this->setEnabled(false);
-        process = new QProcess(this);
+        process = new Q3Process(this);
         process->addArgument("/root/segatex/policygeneration_script");
         process->addArgument("-m");
         process->addArgument(semanageEditLineEdit_str);
@@ -247,8 +252,8 @@ void Policygeneration::readFromOutputFile()
 			QRegExp rx_news("news");
 			QRegExp rx_false("false");
 			QRegExp rx_sync("sync");
-			if ( file.open( IO_ReadOnly ) ) {
-				QTextStream stream( &file );
+			if ( file.open( QIODevice::ReadOnly ) ) {
+				Q3TextStream stream( &file );
 				////////////////////////////////////////////
 				int i,j,k,l,m,n;	
 				if(order_x == 1)
