@@ -23,8 +23,11 @@
 #include <qlineedit.h>
 #include <qpushbutton.h>
 #include <qradiobutton.h>
-#include <qtextedit.h>
-#include <qprocess.h>
+#include <q3textedit.h>
+#include <q3process.h>
+//Added by qt3to4:
+#include <Q3VBoxLayout>
+#include <Q3HBoxLayout>
 
 #include "segatex_core.h"
 #include "segatex_core_process.h"
@@ -47,18 +50,18 @@ SegatexCore::SegatexCore(QWidget *parent, const char *name): QDialog(parent, nam
 		connect(segatex_core2Button, SIGNAL(clicked()), this, SLOT(segatex_core2_clicked()));
 		connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
 
-		QVBoxLayout *leftLayout = new QVBoxLayout;
+		Q3VBoxLayout *leftLayout = new Q3VBoxLayout;
 
-		QVBoxLayout *rightLayout = new QVBoxLayout;
+		Q3VBoxLayout *rightLayout = new Q3VBoxLayout;
 		rightLayout->addWidget(segatex_coreButton);
 		rightLayout->addWidget(segatex_core2Button);
 
-		QHBoxLayout *footLayout = new QHBoxLayout;
+		Q3HBoxLayout *footLayout = new Q3HBoxLayout;
 		footLayout->addStretch(1);
 		footLayout->addWidget(closeButton);
 
 
-		QVBoxLayout *mainLayout = new QVBoxLayout(this);
+		Q3VBoxLayout *mainLayout = new Q3VBoxLayout(this);
 		mainLayout->setMargin(11);
 		mainLayout->setSpacing(6);
 		mainLayout->addLayout(leftLayout);
