@@ -20,7 +20,10 @@
 
 #include <qlayout.h>
 #include <qpushbutton.h>
-#include <qprocess.h>
+#include <q3process.h>
+//Added by qt3to4:
+#include <Q3HBoxLayout>
+#include <Q3VBoxLayout>
 
 #include "segatex_yum_process.h"
 
@@ -31,7 +34,7 @@
 SegatexYumProcess::SegatexYumProcess(QWidget *parent, const char *name): QDialog(parent, name)
 {
 	setCaption(tr("Yum SELinux Process"));
-	textEdit1 = new QTextEdit(this);
+	textEdit1 = new Q3TextEdit(this);
 	textEdit1->setPaletteBackgroundColor(QColor(174,255,185));
 	closeButton = new QPushButton(tr("close"), this);
 	closeButton->setDefault(true);
@@ -39,14 +42,14 @@ SegatexYumProcess::SegatexYumProcess(QWidget *parent, const char *name): QDialog
 	connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
 	connect(closeButton, SIGNAL(clicked()), this, SLOT(close_button_clicked()));
 
-	QVBoxLayout *headLayout = new QVBoxLayout;
+	Q3VBoxLayout *headLayout = new Q3VBoxLayout;
 	headLayout->addWidget(textEdit1);
 
-	QHBoxLayout *footLayout = new QHBoxLayout;
+	Q3HBoxLayout *footLayout = new Q3HBoxLayout;
 	footLayout->addStretch(1);
 	footLayout->addWidget(closeButton);
 
-	QVBoxLayout *mainLayout = new QVBoxLayout(this);
+	Q3VBoxLayout *mainLayout = new Q3VBoxLayout(this);
 	mainLayout->setMargin(11);
 	mainLayout->setSpacing(6);
 	mainLayout->addLayout(headLayout);
@@ -115,7 +118,7 @@ void SegatexYumProcess::processExited1()
 void SegatexYumProcess::yum_install_base_process()
 {
 	this->setEnabled(false);
-	process = new QProcess(this);
+	process = new Q3Process(this);
 	//process->addArgument("sudo");
 	process->addArgument("yum");
 	process->addArgument("-y");
@@ -145,7 +148,7 @@ void SegatexYumProcess::yum_install_base_process()
 void SegatexYumProcess::yum_update_base_process()
 {
 	this->setEnabled(false);
-	process1 = new QProcess(this);
+	process1 = new Q3Process(this);
 	//process1->addArgument("sudo");
 	process1->addArgument("yum");
 	process1->addArgument("-y");
