@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2008 Shintaro Fujiwara 
+ * Copyright (C) 2007-2009 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -293,7 +293,7 @@ void SemanageCoreLoginProcess::semanage_core_base_login_process()
                 char buffer[SIZE_TMP];
                 int chars_read;
                 memset(buffer, '\0', sizeof(buffer));
-                read_fp = popen("/usr/sbin/semanage user -l", "r");
+                read_fp = popen("export LANG=C;/usr/sbin/semanage user -l", "r");
                 if(read_fp != NULL){
                         chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                         while(chars_read>0){
@@ -316,7 +316,7 @@ void SemanageCoreLoginProcess::semanage_core_base_login_process()
                 char buffer[SIZE_TMP];
                 int chars_read;
                 memset(buffer, '\0', sizeof(buffer));
-                read_fp = popen("less /etc/passwd", "r");
+                read_fp = popen("cat /etc/passwd", "r");
                 if(read_fp != NULL){
                         chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                         while(chars_read>0){
