@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2008 Shintaro Fujiwara 
+ * Copyright (C) 2007-2009 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -283,7 +283,7 @@ void SemanageCorePortProcess::semanage_core_base_port_process()
                 int chars_read;
                 memset(buffer, '\0', sizeof(buffer));
 
-                read_fp = popen("semanage port -l", "r");
+                read_fp = popen("export LANG=C;/usr/sbin/semanage port -l", "r");
                 if(read_fp != NULL){
                         chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                         while(chars_read>0){
