@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2008 Shintaro Fujiwara 
+ * Copyright (C) 2007-2009 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -285,7 +285,7 @@ void SemanageCoreProcess::semanage_core_base_process()
                 char buffer[SIZE_TMP];
                 int chars_read;
                 memset(buffer, '\0', sizeof(buffer));
-                read_fp = popen("/usr/sbin/semanage login -l", "r");
+                read_fp = popen("export LANG=C;/usr/sbin/semanage login -l", "r");
                 if(read_fp != NULL){
                         chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                         while(chars_read>0){
@@ -309,7 +309,7 @@ void SemanageCoreProcess::semanage_core_base_process()
                 char buffer[SIZE_TMP];
                 int chars_read;
                 memset(buffer, '\0', sizeof(buffer));
-                read_fp = popen("/usr/sbin/semanage user -l", "r");
+                read_fp = popen("export LANG=C;/usr/sbin/semanage user -l", "r");
                 if(read_fp != NULL){
                         chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                         while(chars_read>0){
@@ -332,7 +332,7 @@ void SemanageCoreProcess::semanage_core_base_process()
                 char buffer[SIZE_TMP];
                 int chars_read;
                 memset(buffer, '\0', sizeof(buffer));
-                read_fp = popen("/usr/sbin/semanage boolean -l", "r");
+                read_fp = popen("export LANG=C;/usr/sbin/semanage boolean -l", "r");
                 if(read_fp != NULL){
                         chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                         while(chars_read>0){
@@ -355,7 +355,7 @@ void SemanageCoreProcess::semanage_core_base_process()
                 char buffer[SIZE_TMP];
                 int chars_read;
                 memset(buffer, '\0', sizeof(buffer));
-                read_fp = popen("/usr/sbin/semanage port -l", "r");
+                read_fp = popen("export LANG=C;/usr/sbin/semanage port -l", "r");
                 if(read_fp != NULL){
                         chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                         while(chars_read>0){
@@ -378,7 +378,7 @@ void SemanageCoreProcess::semanage_core_base_process()
                 char buffer[SIZE_TMP];
                 int chars_read;
                 memset(buffer, '\0', sizeof(buffer));
-                read_fp = popen("/usr/sbin/semanage interface -l", "r");
+                read_fp = popen("export LANG=C;/usr/sbin/semanage interface -l", "r");
                 if(read_fp != NULL){
                         chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                         while(chars_read>0){
@@ -401,7 +401,7 @@ void SemanageCoreProcess::semanage_core_base_process()
                 char buffer[SIZE_TMP];
                 int chars_read;
                 memset(buffer, '\0', sizeof(buffer));
-                read_fp = popen("/usr/sbin/semanage fcontext -l", "r");
+                read_fp = popen("export LANG=C;/usr/sbin/semanage fcontext -l", "r");
                 if(read_fp != NULL){
                         chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                         while(chars_read>0){
@@ -424,7 +424,7 @@ void SemanageCoreProcess::semanage_core_base_process()
                 char buffer[SIZE_TMP];
                 int chars_read;
                 memset(buffer, '\0', sizeof(buffer));
-                read_fp = popen("/usr/sbin/semanage translation -l", "r");
+                read_fp = popen("export LANG=C;/usr/sbin/semanage translation -l", "r");
                 if(read_fp != NULL){
                         chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                         while(chars_read>0){
