@@ -181,7 +181,9 @@ void Useradd::useradd_base_process(QString username_str, QString passwordEditLin
 	connect(process, SIGNAL(processExited()),this,SLOT(processExited()));
 	process->start();
 
-	readFromOutputFile();
+	sleep(5);
+	//readFromOutputFile();
+	readfromfile_clicked();
 }
 void Useradd::userdel_base_process(QString username_str)
 {
@@ -199,7 +201,9 @@ void Useradd::userdel_base_process(QString username_str)
 	connect(process, SIGNAL(processExited()),this,SLOT(processExited()));
 	process->start();
 
-	readFromOutputFile();
+	sleep(10);
+	//readFromOutputFile();
+	readfromfile_clicked();
 }
 
 //this slot should be called from above slot
